checkproto

package module
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 11, 2026 License: MIT Imports: 3 Imported by: 0

README

checkproto

License MIT Go version Test Coverage Status Release Go Reference

Protobuf message comparison for https://github.com/powerman/check.

Import this package as a blank import in your test file or TestMain to enable proto.Equal comparison via check.DeepEqual/check.NotDeepEqual.

Documentation

Overview

Package checkproto provides protobuf message comparison for github.com/powerman/check.

Import this package as a blank import in your test file or TestMain to enable proto.Equal comparison via check.DeepEqual/NotDeepEqual:

import _ "github.com/powerman/checkproto"

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EqualProto

func EqualProto(actual, expected any) (equal, ok bool)

EqualProto compares two values using proto.Equal when both implement protoreflect.ProtoMessage. If only one side is a proto message they are reported as unequal (claimed). Otherwise the checker does not apply.

Types

This section is empty.

Jump to