Documentation
¶
Overview ¶
Package checkproto provides protobuf message comparison for github.com/powerman/check.
Import this package as a blank import in your test file or TestMain to enable proto.Equal comparison via check.DeepEqual/NotDeepEqual:
import _ "github.com/powerman/checkproto"
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EqualProto ¶
EqualProto compares two values using proto.Equal when both implement protoreflect.ProtoMessage. If only one side is a proto message they are reported as unequal (claimed). Otherwise the checker does not apply.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.